# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/virtualvolume/v1/virtualvolume.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/virtualvolume/v1/virtualvolume.proto',
  package='github.com.metaprov.modelaapi.services.virtualvolume.v1',
  syntax='proto3',
  serialized_options=b'Z7github.com/metaprov/modelaapi/services/virtualvolume/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nKgithub.com/metaprov/modelaapi/services/virtualvolume/v1/virtualvolume.proto\x12\x37github.com.metaprov.modelaapi.services.virtualvolume.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xcd\x01\n\x19ListVirtualVolumesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12n\n\x06labels\x18\x03 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"u\n\x1aListVirtualVolumesResponse\x12W\n\x05items\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolumeList\"\x17\n\x15VirtualVolumeResponse\"p\n\x1a\x43reateVirtualVolumeRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x1d\n\x1b\x43reateVirtualVolumeResponse\"p\n\x1aUpdateVirtualVolumeRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x1d\n\x1bUpdateVirtualVolumeResponse\":\n\x17GetVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"|\n\x18GetVirtualVolumeResponse\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"=\n\x1a\x44\x65leteVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1d\n\x1b\x44\x65leteVirtualVolumeResponse2\x88\t\n\x14VirtualVolumeService\x12\xdd\x01\n\x12ListVirtualVolumes\x12R.github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest\x1aS.github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/virtualvolumes\x12\xdf\x01\n\x13\x43reateVirtualVolume\x12S.github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeRequest\x1aT.github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/virtualvolumes:\x01*\x12\xde\x01\n\x10GetVirtualVolume\x12P.github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeRequest\x1aQ.github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/api/v1/virtualvolumes/{name}\x12\xe6\x01\n\x13UpdateVirtualVolume\x12S.github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeRequest\x1aT.github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeResponse\"$\x82\xd3\xe4\x93\x02\x1e\x1a\x19/v1/virtualvolumes/{name}:\x01*\x12\xe3\x01\n\x13\x44\x65leteVirtualVolume\x12S.github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeRequest\x1aT.github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeResponse\"!\x82\xd3\xe4\x93\x02\x1b*\x19/v1/virtualvolumes/{name}B9Z7github.com/metaprov/modelaapi/services/virtualvolume/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTVIRTUALVOLUMESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=461,
  serialized_end=506,
)

_LISTVIRTUALVOLUMESREQUEST = _descriptor.Descriptor(
  name='ListVirtualVolumesRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTVIRTUALVOLUMESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=506,
)


_LISTVIRTUALVOLUMESRESPONSE = _descriptor.Descriptor(
  name='ListVirtualVolumesResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=625,
)


_VIRTUALVOLUMERESPONSE = _descriptor.Descriptor(
  name='VirtualVolumeResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=650,
)


_CREATEVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='CreateVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=764,
)


_CREATEVIRTUALVOLUMERESPONSE = _descriptor.Descriptor(
  name='CreateVirtualVolumeResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=795,
)


_UPDATEVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=797,
  serialized_end=909,
)


_UPDATEVIRTUALVOLUMERESPONSE = _descriptor.Descriptor(
  name='UpdateVirtualVolumeResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=940,
)


_GETVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='GetVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=942,
  serialized_end=1000,
)


_GETVIRTUALVOLUMERESPONSE = _descriptor.Descriptor(
  name='GetVirtualVolumeResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1126,
)


_DELETEVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1128,
  serialized_end=1189,
)


_DELETEVIRTUALVOLUMERESPONSE = _descriptor.Descriptor(
  name='DeleteVirtualVolumeResponse',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1191,
  serialized_end=1220,
)

_LISTVIRTUALVOLUMESREQUEST_LABELSENTRY.containing_type = _LISTVIRTUALVOLUMESREQUEST
_LISTVIRTUALVOLUMESREQUEST.fields_by_name['labels'].message_type = _LISTVIRTUALVOLUMESREQUEST_LABELSENTRY
_LISTVIRTUALVOLUMESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUMELIST
_CREATEVIRTUALVOLUMEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME
_UPDATEVIRTUALVOLUMEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME
_GETVIRTUALVOLUMERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME
DESCRIPTOR.message_types_by_name['ListVirtualVolumesRequest'] = _LISTVIRTUALVOLUMESREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualVolumesResponse'] = _LISTVIRTUALVOLUMESRESPONSE
DESCRIPTOR.message_types_by_name['VirtualVolumeResponse'] = _VIRTUALVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['CreateVirtualVolumeRequest'] = _CREATEVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualVolumeResponse'] = _CREATEVIRTUALVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['UpdateVirtualVolumeRequest'] = _UPDATEVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualVolumeResponse'] = _UPDATEVIRTUALVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualVolumeRequest'] = _GETVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['GetVirtualVolumeResponse'] = _GETVIRTUALVOLUMERESPONSE
DESCRIPTOR.message_types_by_name['DeleteVirtualVolumeRequest'] = _DELETEVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualVolumeResponse'] = _DELETEVIRTUALVOLUMERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListVirtualVolumesRequest = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTVIRTUALVOLUMESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesRequest)
  })
_sym_db.RegisterMessage(ListVirtualVolumesRequest)
_sym_db.RegisterMessage(ListVirtualVolumesRequest.LabelsEntry)

ListVirtualVolumesResponse = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.ListVirtualVolumesResponse)
  })
_sym_db.RegisterMessage(ListVirtualVolumesResponse)

VirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('VirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _VIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeResponse)
  })
_sym_db.RegisterMessage(VirtualVolumeResponse)

CreateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(CreateVirtualVolumeRequest)

CreateVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('CreateVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.CreateVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(CreateVirtualVolumeResponse)

UpdateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualVolumeRequest)

UpdateVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('UpdateVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.UpdateVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(UpdateVirtualVolumeResponse)

GetVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('GetVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(GetVirtualVolumeRequest)

GetVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('GetVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.GetVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(GetVirtualVolumeResponse)

DeleteVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualVolumeRequest)

DeleteVirtualVolumeResponse = _reflection.GeneratedProtocolMessageType('DeleteVirtualVolumeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALVOLUMERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.virtualvolume.v1.virtualvolume_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.virtualvolume.v1.DeleteVirtualVolumeResponse)
  })
_sym_db.RegisterMessage(DeleteVirtualVolumeResponse)


DESCRIPTOR._options = None
_LISTVIRTUALVOLUMESREQUEST_LABELSENTRY._options = None

_VIRTUALVOLUMESERVICE = _descriptor.ServiceDescriptor(
  name='VirtualVolumeService',
  full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1223,
  serialized_end=2383,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListVirtualVolumes',
    full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService.ListVirtualVolumes',
    index=0,
    containing_service=None,
    input_type=_LISTVIRTUALVOLUMESREQUEST,
    output_type=_LISTVIRTUALVOLUMESRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/api/v1/virtualvolumes',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService.CreateVirtualVolume',
    index=1,
    containing_service=None,
    input_type=_CREATEVIRTUALVOLUMEREQUEST,
    output_type=_CREATEVIRTUALVOLUMERESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/virtualvolumes:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService.GetVirtualVolume',
    index=2,
    containing_service=None,
    input_type=_GETVIRTUALVOLUMEREQUEST,
    output_type=_GETVIRTUALVOLUMERESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/api/v1/virtualvolumes/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService.UpdateVirtualVolume',
    index=3,
    containing_service=None,
    input_type=_UPDATEVIRTUALVOLUMEREQUEST,
    output_type=_UPDATEVIRTUALVOLUMERESPONSE,
    serialized_options=b'\202\323\344\223\002\036\032\031/v1/virtualvolumes/{name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.virtualvolume.v1.VirtualVolumeService.DeleteVirtualVolume',
    index=4,
    containing_service=None,
    input_type=_DELETEVIRTUALVOLUMEREQUEST,
    output_type=_DELETEVIRTUALVOLUMERESPONSE,
    serialized_options=b'\202\323\344\223\002\033*\031/v1/virtualvolumes/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALVOLUMESERVICE)

DESCRIPTOR.services_by_name['VirtualVolumeService'] = _VIRTUALVOLUMESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/runtime/schema/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='k8s.io/apimachinery/pkg/runtime/schema/generated.proto',
  package='k8s.io.apimachinery.pkg.runtime.schema',
  syntax='proto2',
  serialized_options=b'Z\006schema',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6k8s.io/apimachinery/pkg/runtime/schema/generated.proto\x12&k8s.io.apimachinery.pkg.runtime.schemaB\x08Z\x06schema'
)



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/labelingpipeline/v1/labelingpipeline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/labelingpipeline/v1/labelingpipeline.proto',
  package='github.com.metaprov.modelaapi.services.labelingpipeline.v1',
  syntax='proto3',
  serialized_options=b'Z:github.com/metaprov/modelaapi/services/labelingpipeline/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQgithub.com/metaprov/modelaapi/services/labelingpipeline/v1/labelingpipeline.proto\x12:github.com.metaprov.modelaapi.services.labelingpipeline.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd4\x01\n\x1bListLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12s\n\x06labels\x18\x02 \x03(\x0b\x32\x63.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"y\n\x1cListLabelingPipelineResponse\x12Y\n\x05items\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineList\"u\n\x1d\x43reateLabelingPipelineRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\" \n\x1e\x43reateLabelingPipelineResponse\"u\n\x1dUpdateLabelingPipelineRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\" \n\x1eUpdateLabelingPipelineResponse\"=\n\x1aGetLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x81\x01\n\x1bGetLabelingPipelineResponse\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteLabelingPipelineResponse\"\x1f\n\x1dPauseLabelingPipelineResponse\"?\n\x1cPauseLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1eResumeLabelingPipelineResponse\"@\n\x1dResumeLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xd2\r\n\x17LabelingPipelineService\x12\xe6\x01\n\x15ListLabelingPipelines\x12W.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest\x1aX.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/labelpipelines\x12\xee\x01\n\x16\x43reateLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/labelpipelines:\x01*\x12\xe9\x01\n\x13GetLabelingPipeline\x12V.github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest\x1aW.github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/labelpipelines/{name}\x12\x84\x02\n\x16UpdateLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineResponse\"3\x82\xd3\xe4\x93\x02-\x1a(/v1/labelpipelines/{label.metadata.name}:\x01*\x12\xd1\x01\n\x16\x44\x65leteLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineResponse\"\x00\x12\x87\x02\n\x15PauseLabelingPipeline\x12X.github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest\x1aY.github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineResponse\"9\x82\xd3\xe4\x93\x02\x33\x1a./v1/labelpipelines/{label.metadata.name}:pause:\x01*\x12\x8b\x02\n\x16ResumeLabelingPipeline\x12Y.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest\x1aZ.github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineResponse\":\x82\xd3\xe4\x93\x02\x34\x1a//v1/labelpipelines/{label.metadata.name}:resume:\x01*B<Z:github.com/metaprov/modelaapi/services/labelingpipeline/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTLABELINGPIPELINEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=458,
)

_LISTLABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='ListLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTLABELINGPIPELINEREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=458,
)


_LISTLABELINGPIPELINERESPONSE = _descriptor.Descriptor(
  name='ListLabelingPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=460,
  serialized_end=581,
)


_CREATELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=583,
  serialized_end=700,
)


_CREATELABELINGPIPELINERESPONSE = _descriptor.Descriptor(
  name='CreateLabelingPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=702,
  serialized_end=734,
)


_UPDATELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=853,
)


_UPDATELABELINGPIPELINERESPONSE = _descriptor.Descriptor(
  name='UpdateLabelingPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=887,
)


_GETLABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=889,
  serialized_end=950,
)


_GETLABELINGPIPELINERESPONSE = _descriptor.Descriptor(
  name='GetLabelingPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1082,
)


_DELETELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1084,
  serialized_end=1148,
)


_DELETELABELINGPIPELINERESPONSE = _descriptor.Descriptor(
  name='DeleteLabelingPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1150,
  serialized_end=1182,
)


_PAUSELABELINGPIPELINERESPONSE = _descriptor.Descriptor(
  name='PauseLabelingPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1184,
  serialized_end=1215,
)


_PAUSELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='PauseLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1217,
  serialized_end=1280,
)


_RESUMELABELINGPIPELINERESPONSE = _descriptor.Descriptor(
  name='ResumeLabelingPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1282,
  serialized_end=1314,
)


_RESUMELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='ResumeLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1380,
)

_LISTLABELINGPIPELINEREQUEST_LABELSENTRY.containing_type = _LISTLABELINGPIPELINEREQUEST
_LISTLABELINGPIPELINEREQUEST.fields_by_name['labels'].message_type = _LISTLABELINGPIPELINEREQUEST_LABELSENTRY
_LISTLABELINGPIPELINERESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINELIST
_CREATELABELINGPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE
_UPDATELABELINGPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE
_GETLABELINGPIPELINERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE
DESCRIPTOR.message_types_by_name['ListLabelingPipelineRequest'] = _LISTLABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ListLabelingPipelineResponse'] = _LISTLABELINGPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRequest'] = _CREATELABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateLabelingPipelineResponse'] = _CREATELABELINGPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRequest'] = _UPDATELABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineResponse'] = _UPDATELABELINGPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['GetLabelingPipelineRequest'] = _GETLABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['GetLabelingPipelineResponse'] = _GETLABELINGPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRequest'] = _DELETELABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineResponse'] = _DELETELABELINGPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['PauseLabelingPipelineResponse'] = _PAUSELABELINGPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['PauseLabelingPipelineRequest'] = _PAUSELABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ResumeLabelingPipelineResponse'] = _RESUMELABELINGPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['ResumeLabelingPipelineRequest'] = _RESUMELABELINGPIPELINEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABELINGPIPELINEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRequest)
_sym_db.RegisterMessage(ListLabelingPipelineRequest.LabelsEntry)

ListLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ListLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineResponse)

CreateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRequest)

CreateLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.CreateLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineResponse)

UpdateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRequest)

UpdateLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.UpdateLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineResponse)

GetLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRequest)

GetLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.GetLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(GetLabelingPipelineResponse)

DeleteLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRequest)

DeleteLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.DeleteLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineResponse)

PauseLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('PauseLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(PauseLabelingPipelineResponse)

PauseLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('PauseLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.PauseLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(PauseLabelingPipelineRequest)

ResumeLabelingPipelineResponse = _reflection.GeneratedProtocolMessageType('ResumeLabelingPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMELABELINGPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineResponse)
  })
_sym_db.RegisterMessage(ResumeLabelingPipelineResponse)

ResumeLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('ResumeLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipeline.v1.labelingpipeline_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipeline.v1.ResumeLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(ResumeLabelingPipelineRequest)


DESCRIPTOR._options = None
_LISTLABELINGPIPELINEREQUEST_LABELSENTRY._options = None

_LABELINGPIPELINESERVICE = _descriptor.ServiceDescriptor(
  name='LabelingPipelineService',
  full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1383,
  serialized_end=3129,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListLabelingPipelines',
    full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService.ListLabelingPipelines',
    index=0,
    containing_service=None,
    input_type=_LISTLABELINGPIPELINEREQUEST,
    output_type=_LISTLABELINGPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/v1/labelpipelines',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService.CreateLabelingPipeline',
    index=1,
    containing_service=None,
    input_type=_CREATELABELINGPIPELINEREQUEST,
    output_type=_CREATELABELINGPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/labelpipelines:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService.GetLabelingPipeline',
    index=2,
    containing_service=None,
    input_type=_GETLABELINGPIPELINEREQUEST,
    output_type=_GETLABELINGPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/v1/labelpipelines/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService.UpdateLabelingPipeline',
    index=3,
    containing_service=None,
    input_type=_UPDATELABELINGPIPELINEREQUEST,
    output_type=_UPDATELABELINGPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\002-\032(/v1/labelpipelines/{label.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService.DeleteLabelingPipeline',
    index=4,
    containing_service=None,
    input_type=_DELETELABELINGPIPELINEREQUEST,
    output_type=_DELETELABELINGPIPELINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService.PauseLabelingPipeline',
    index=5,
    containing_service=None,
    input_type=_PAUSELABELINGPIPELINEREQUEST,
    output_type=_PAUSELABELINGPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\0023\032./v1/labelpipelines/{label.metadata.name}:pause:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.labelingpipeline.v1.LabelingPipelineService.ResumeLabelingPipeline',
    index=6,
    containing_service=None,
    input_type=_RESUMELABELINGPIPELINEREQUEST,
    output_type=_RESUMELABELINGPIPELINERESPONSE,
    serialized_options=b'\202\323\344\223\0024\032//v1/labelpipelines/{label.metadata.name}:resume:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LABELINGPIPELINESERVICE)

DESCRIPTOR.services_by_name['LabelingPipelineService'] = _LABELINGPIPELINESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/todo/v1/todo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/todo/v1/todo.proto',
  package='github.com.metaprov.modelaapi.services.todo.v1',
  syntax='proto3',
  serialized_options=b'Z.github.com/metaprov/modelaapi/services/todo/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9github.com/metaprov/modelaapi/services/todo/v1/todo.proto\x12.github.com.metaprov.modelaapi.services.todo.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xb2\x01\n\x10ListTodosRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\\\n\x06labels\x18\x02 \x03(\x0b\x32L.github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n\x11ListTodosResponse\x12M\n\x05items\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList\"\x0e\n\x0cTodoResponse\"o\n\x11\x43reateTodoRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x10\n\x08password\x18\x02 \x01(\t\"\x14\n\x12\x43reateTodoResponse\"]\n\x11UpdateTodoRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x14\n\x12UpdateTodoResponse\"1\n\x0eGetTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x0fGetTodoResponse\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x0c\n\x04yaml\x18\x02 \x01(\t\";\n\x18GetTodoNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x19GetTodoNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"4\n\x11\x44\x65leteTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteTodoResponse\"\x14\n\x12TodoCreateResponse\"7\n\x14TodoGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\"\n\x11TodoLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t2\xb4\x07\n\x0bTodoService\x12\xa3\x01\n\tListTodos\x12@.github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest\x1a\x41.github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/v1/todos\x12\xac\x01\n\nCreateTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.CreateTodoResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\t/v1/todos:\x04todo\x12\xb0\x01\n\x07GetTodo\x12>.github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest\x1a?.github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1/{namespace}/todos/{name}\x12\xdc\x01\n\nUpdateTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoResponse\"G\x82\xd3\xe4\x93\x02\x41\x1a\x39/v1/{todo.metadata.namespace}/todos//{todo.metadata.name}:\x04todo\x12\xbd\x01\n\nDeleteTodo\x12\x41.github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest\x1a\x42.github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoResponse\"(\x82\xd3\xe4\x93\x02\"* /api/{namespace}/v1/todos/{name}B0Z.github.com/metaprov/modelaapi/services/todo/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTTODOSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=451,
)

_LISTTODOSREQUEST = _descriptor.Descriptor(
  name='ListTodosRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTTODOSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=451,
)


_LISTTODOSRESPONSE = _descriptor.Descriptor(
  name='ListTodosResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=453,
  serialized_end=551,
)


_TODORESPONSE = _descriptor.Descriptor(
  name='TodoResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=567,
)


_CREATETODOREQUEST = _descriptor.Descriptor(
  name='CreateTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=680,
)


_CREATETODORESPONSE = _descriptor.Descriptor(
  name='CreateTodoResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.CreateTodoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=702,
)


_UPDATETODOREQUEST = _descriptor.Descriptor(
  name='UpdateTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=797,
)


_UPDATETODORESPONSE = _descriptor.Descriptor(
  name='UpdateTodoResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=819,
)


_GETTODOREQUEST = _descriptor.Descriptor(
  name='GetTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=821,
  serialized_end=870,
)


_GETTODORESPONSE = _descriptor.Descriptor(
  name='GetTodoResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=872,
  serialized_end=977,
)


_GETTODONAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetTodoNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=979,
  serialized_end=1038,
)


_GETTODONAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetTodoNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.todo.v1.GetTodoNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1040,
  serialized_end=1152,
)


_DELETETODOREQUEST = _descriptor.Descriptor(
  name='DeleteTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1206,
)


_DELETETODORESPONSE = _descriptor.Descriptor(
  name='DeleteTodoResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1228,
)


_TODOCREATERESPONSE = _descriptor.Descriptor(
  name='TodoCreateResponse',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1230,
  serialized_end=1250,
)


_TODOGETBYNAMEREQUEST = _descriptor.Descriptor(
  name='TodoGetByNameRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoGetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoGetByNameRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoGetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1252,
  serialized_end=1307,
)


_TODOLOGOUTREQUEST = _descriptor.Descriptor(
  name='TodoLogoutRequest',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoLogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoLogoutRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1343,
)

_LISTTODOSREQUEST_LABELSENTRY.containing_type = _LISTTODOSREQUEST
_LISTTODOSREQUEST.fields_by_name['labels'].message_type = _LISTTODOSREQUEST_LABELSENTRY
_LISTTODOSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODOLIST
_CREATETODOREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO
_UPDATETODOREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO
_GETTODORESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO
_GETTODONAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListTodosRequest'] = _LISTTODOSREQUEST
DESCRIPTOR.message_types_by_name['ListTodosResponse'] = _LISTTODOSRESPONSE
DESCRIPTOR.message_types_by_name['TodoResponse'] = _TODORESPONSE
DESCRIPTOR.message_types_by_name['CreateTodoRequest'] = _CREATETODOREQUEST
DESCRIPTOR.message_types_by_name['CreateTodoResponse'] = _CREATETODORESPONSE
DESCRIPTOR.message_types_by_name['UpdateTodoRequest'] = _UPDATETODOREQUEST
DESCRIPTOR.message_types_by_name['UpdateTodoResponse'] = _UPDATETODORESPONSE
DESCRIPTOR.message_types_by_name['GetTodoRequest'] = _GETTODOREQUEST
DESCRIPTOR.message_types_by_name['GetTodoResponse'] = _GETTODORESPONSE
DESCRIPTOR.message_types_by_name['GetTodoNamespacesRequest'] = _GETTODONAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetTodoNamespacesResponse'] = _GETTODONAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteTodoRequest'] = _DELETETODOREQUEST
DESCRIPTOR.message_types_by_name['DeleteTodoResponse'] = _DELETETODORESPONSE
DESCRIPTOR.message_types_by_name['TodoCreateResponse'] = _TODOCREATERESPONSE
DESCRIPTOR.message_types_by_name['TodoGetByNameRequest'] = _TODOGETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['TodoLogoutRequest'] = _TODOLOGOUTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListTodosRequest = _reflection.GeneratedProtocolMessageType('ListTodosRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTTODOSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTTODOSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosRequest)
  })
_sym_db.RegisterMessage(ListTodosRequest)
_sym_db.RegisterMessage(ListTodosRequest.LabelsEntry)

ListTodosResponse = _reflection.GeneratedProtocolMessageType('ListTodosResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.ListTodosResponse)
  })
_sym_db.RegisterMessage(ListTodosResponse)

TodoResponse = _reflection.GeneratedProtocolMessageType('TodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _TODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.TodoResponse)
  })
_sym_db.RegisterMessage(TodoResponse)

CreateTodoRequest = _reflection.GeneratedProtocolMessageType('CreateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.CreateTodoRequest)
  })
_sym_db.RegisterMessage(CreateTodoRequest)

CreateTodoResponse = _reflection.GeneratedProtocolMessageType('CreateTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.CreateTodoResponse)
  })
_sym_db.RegisterMessage(CreateTodoResponse)

UpdateTodoRequest = _reflection.GeneratedProtocolMessageType('UpdateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoRequest)
  })
_sym_db.RegisterMessage(UpdateTodoRequest)

UpdateTodoResponse = _reflection.GeneratedProtocolMessageType('UpdateTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.UpdateTodoResponse)
  })
_sym_db.RegisterMessage(UpdateTodoResponse)

GetTodoRequest = _reflection.GeneratedProtocolMessageType('GetTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoRequest)
  })
_sym_db.RegisterMessage(GetTodoRequest)

GetTodoResponse = _reflection.GeneratedProtocolMessageType('GetTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoResponse)
  })
_sym_db.RegisterMessage(GetTodoResponse)

GetTodoNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetTodoNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTODONAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoNamespacesRequest)
  })
_sym_db.RegisterMessage(GetTodoNamespacesRequest)

GetTodoNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetTodoNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTODONAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.GetTodoNamespacesResponse)
  })
_sym_db.RegisterMessage(GetTodoNamespacesResponse)

DeleteTodoRequest = _reflection.GeneratedProtocolMessageType('DeleteTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoRequest)
  })
_sym_db.RegisterMessage(DeleteTodoRequest)

DeleteTodoResponse = _reflection.GeneratedProtocolMessageType('DeleteTodoResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODORESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.DeleteTodoResponse)
  })
_sym_db.RegisterMessage(DeleteTodoResponse)

TodoCreateResponse = _reflection.GeneratedProtocolMessageType('TodoCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _TODOCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.TodoCreateResponse)
  })
_sym_db.RegisterMessage(TodoCreateResponse)

TodoGetByNameRequest = _reflection.GeneratedProtocolMessageType('TodoGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _TODOGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.TodoGetByNameRequest)
  })
_sym_db.RegisterMessage(TodoGetByNameRequest)

TodoLogoutRequest = _reflection.GeneratedProtocolMessageType('TodoLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _TODOLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.todo.v1.todo_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.todo.v1.TodoLogoutRequest)
  })
_sym_db.RegisterMessage(TodoLogoutRequest)


DESCRIPTOR._options = None
_LISTTODOSREQUEST_LABELSENTRY._options = None

_TODOSERVICE = _descriptor.ServiceDescriptor(
  name='TodoService',
  full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1346,
  serialized_end=2294,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListTodos',
    full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoService.ListTodos',
    index=0,
    containing_service=None,
    input_type=_LISTTODOSREQUEST,
    output_type=_LISTTODOSRESPONSE,
    serialized_options=b'\202\323\344\223\002\013\022\t/v1/todos',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTodo',
    full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoService.CreateTodo',
    index=1,
    containing_service=None,
    input_type=_CREATETODOREQUEST,
    output_type=_CREATETODORESPONSE,
    serialized_options=b'\202\323\344\223\002\021\"\t/v1/todos:\004todo',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTodo',
    full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoService.GetTodo',
    index=2,
    containing_service=None,
    input_type=_GETTODOREQUEST,
    output_type=_GETTODORESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/v1/{namespace}/todos/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTodo',
    full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoService.UpdateTodo',
    index=3,
    containing_service=None,
    input_type=_UPDATETODOREQUEST,
    output_type=_UPDATETODORESPONSE,
    serialized_options=b'\202\323\344\223\002A\0329/v1/{todo.metadata.namespace}/todos//{todo.metadata.name}:\004todo',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTodo',
    full_name='github.com.metaprov.modelaapi.services.todo.v1.TodoService.DeleteTodo',
    index=4,
    containing_service=None,
    input_type=_DELETETODOREQUEST,
    output_type=_DELETETODORESPONSE,
    serialized_options=b'\202\323\344\223\002\"* /api/{namespace}/v1/todos/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TODOSERVICE)

DESCRIPTOR.services_by_name['TodoService'] = _TODOSERVICE

# @@protoc_insertion_point(module_scope)
